Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type PatternNode ¶
type PatternNode struct {
// contains filtered or unexported fields
}
PatternNode represents a node in the pattern tree
type PatternTree ¶
type PatternTree struct {
// contains filtered or unexported fields
}
func NewPatternTree ¶
func NewPatternTree() *PatternTree
func (*PatternTree) AddPattern ¶
func (tree *PatternTree) AddPattern(pattern string)
AddPattern adds a pattern to the tree
func (*PatternTree) Matches ¶
func (tree *PatternTree) Matches(eventType string) bool
Matches checks if an event type matches any pattern in the tree with caching
func (*PatternTree) MatchesPattern ¶
func (tree *PatternTree) MatchesPattern(pattern, eventType string) bool
MatchesPattern checks if an event matches a specific pattern
Click to show internal directories.
Click to hide internal directories.